summaryrefslogtreecommitdiffstats
path: root/sys/amd64/include/reloc.h
diff options
context:
space:
mode:
authorjkh <jkh@FreeBSD.org>1994-08-09 14:39:57 +0000
committerjkh <jkh@FreeBSD.org>1994-08-09 14:39:57 +0000
commite6e4d38831ed0ece1a3a3857a74daef5c372d6aa (patch)
treea45219b1ad70f525ee5d077ca304c7fff64322b2 /sys/amd64/include/reloc.h
parent726074b4a467a32fd9edfc5382816d634bca2f71 (diff)
downloadFreeBSD-src-e6e4d38831ed0ece1a3a3857a74daef5c372d6aa.zip
FreeBSD-src-e6e4d38831ed0ece1a3a3857a74daef5c372d6aa.tar.gz
Merge in the necessary bits from 1.1.5.1 to make exec.h and reloc.h
happy campers again (e.g. match our own exec format). This should make ld happy. Submitted by: jkh
Diffstat (limited to 'sys/amd64/include/reloc.h')
-rw-r--r--sys/amd64/include/reloc.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/sys/amd64/include/reloc.h b/sys/amd64/include/reloc.h
index 28b10c1..fc3b5cb 100644
--- a/sys/amd64/include/reloc.h
+++ b/sys/amd64/include/reloc.h
@@ -31,15 +31,18 @@
* SUCH DAMAGE.
*
* @(#)reloc.h 8.1 (Berkeley) 6/10/93
- * $Id$
+ * $Id: reloc.h,v 1.2 1994/08/02 07:38:59 davidg Exp $
*/
/* Relocation format. */
struct relocation_info {
- int r_address; /* offset in text or data segment */
- unsigned int r_symbolnum : 24, /* ordinal number of add symbol */
- r_pcrel : 1, /* 1 if value should be pc-relative */
- r_length : 2, /* log base 2 of value's width */
- r_extern : 1, /* 1 if need to add symbol to value */
- : 4; /* reserved */
+ int r_address; /* offset in text or data segment */
+ unsigned int r_symbolnum : 24, /* ordinal number of add symbol */
+ r_pcrel : 1, /* 1 if value should be pc-relative */
+ r_length : 2, /* log base 2 of value's width */
+ r_extern : 1, /* 1 if need to add symbol to value */
+ r_baserel : 1, /* linkage table relative */
+ r_jmptable : 1, /* relocate to jump table */
+ r_relative : 1, /* load address relative */
+ r_copy : 1; /* run time copy */
};
OpenPOWER on IntegriCloud